<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:umbraco.library="urn:umbraco.library"
    exclude-result-prefixes="umbraco.library"
>

    <xsl:output method="xml" indent="yes" omit-xml-declaration="yes" />

    <xsl:param name="currentPage" />

    <!-- Specify level of the top node for a language (usually 1) -->
    <xsl:variable name="level" select="1" />

    <!-- Grab the top node -->
    <xsl:variable name="siteRoot" select="$currentPage/ancestor-or-self::*[@level = $level]" />

    <xsl:template match="/">
        <ul class="menu">
            <!-- Create the Home link -->
            <li>
                <xsl:if test="$currentPage/@id = $siteRoot/@id">
                    <xsl:attribute name="class">sel</xsl:attribute>
                </xsl:if>
                <a href="{umbraco.library:NiceUrl($siteRoot/@id)}">
					<xsl:value-of select="$siteRoot/@nodeName" />
				</a>
            </li>
            <!-- Process all children of $siteRoot (if any) -->
            <xsl:apply-templates select="$siteRoot/*[@isDoc][not(umbracoNaviHide = 1)]" />
        </ul>
    </xsl:template>

    <!-- Generic template for all nav links -->
    <xsl:template match="*[@isDoc]">
        <li>
            <xsl:if test="@id = $currentPage/@id">
                <xsl:attribute name="class">sel</xsl:attribute>
            </xsl:if>
            <a href="{umbraco.library:NiceUrl(@id)}">
                <xsl:value-of select="@nodeName" />
            </a>
            <!-- Render sub menu if necessary -->
            <xsl:call-template name="submenu" />
        </li>
    </xsl:template>

    <!-- Template for Inactive links -->
    <xsl:template match="*[@isDoc][umbracoNaviInactive = 1]">
        <li>
            <xsl:if test="@id = $currentPage/@id">
                <xsl:attribute name="class">sel</xsl:attribute>
            </xsl:if>
            <span>
                <xsl:value-of select="@nodeName" />
            </span>
            <!-- Submenu? -->
            <xsl:call-template name="submenu" />
        </li>
    </xsl:template>

    <!-- Template checking for, and processing any submenu -->
    <xsl:template name="submenu">
        <xsl:variable name="subPages" select="*[@isDoc][not(umbracoNaviHide = 1)]" />
        <xsl:if test="$subPages">
            <ul>
                <xsl:apply-templates select="$subPages" />
            </ul>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>
